==> kreetingkard-0.4.2.tar.gz: kreetingkard/src/kkpropertyitemimage.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Tasuku Suzuki                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KKPROPERTYITEMIMAGE_H
#define KKPROPERTYITEMIMAGE_H

#include <kpushbutton.h>

#include "kkpropertyitembase.h"

class KKPropertyItemImage : public KKPropertyItemBase
{
	Q_OBJECT
public:
	KKPropertyItemImage( KKProperty* parent, QString text );
	~KKPropertyItemImage();

public slots:
	void reset();
	void start();
	void accept();

private:
	KPushButton* btnRequest;
	KPushButton* btnErase;

private slots:
	void imageRequest();
	void imageErase();
};

#endif //KKPROPERTYITEMIMAGE_H

==> kreetingkard-0.4.3.tar.gz: kreetingkard/src/kkpropertyitemimage.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Tasuku Suzuki                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KKPROPERTYITEMIMAGE_H
#define KKPROPERTYITEMIMAGE_H

#include <kpushbutton.h>

#include "kkpropertyitembase.h"

class KKPropertyItemImage : public KKPropertyItemBase
{
	Q_OBJECT
public:
	KKPropertyItemImage( KKProperty* parent, const QString &text );
	~KKPropertyItemImage();

public slots:
	void reset();
	void start();
	void accept();

private:
	KPushButton* btnRequest;
	KPushButton* btnErase;

private slots:
	void imageRequest();
	void imageErase();
};

#endif //KKPROPERTYITEMIMAGE_H
